﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Net;
using Newtonsoft.Json;
using Newtonsoft.Json.Linq;

namespace ByteScoutWebApiExample
{
	class Program
	{
		// The authentication key (API Key).
		// Get your own by registering at https://app.pdf.co
		const String API_KEY = "***********************************";

        // Direct URL of source PDF file.
        // You can also upload your own file into PDF.co and use it as url. Check "Upload File" samples for code snippets: https://github.com/bytescout/pdf-co-api-samples/tree/master/File%20Upload/
        const string SourceFileUrl = "https://bytescout-com.s3.amazonaws.com/files/demo-files/cloud-api/pdf-to-text/sample.pdf";
		// Comma-separated list of page indices (or ranges) to process. Leave empty for all pages. Example: '0,2-5,7-'.
		const string Pages = "";
		// PDF document password. Leave empty for unprotected documents.
		const string Password = "";
		// Destination TXT file name
		const string DestinationFile = @".\result.txt";

		/*
		Some of advanced options available through profiles:
		(JSON can be single/double-quoted and contain comments.)
		{
		    "profiles": [
		        {
		            "profile1": {                
		                "ExtractInvisibleText": true, // Invisible text extraction. Values: true / false
		                "ExtractShadowLikeText": true, // Shadow-like text extraction. Values: true / false
		                "ExtractAnnotations": true, // Whether to extract PDF annotations.
		                "CheckPermissions": true, // Ignore document permissions. Values: true / false
		                "DetectNewColumnBySpacesRatio": 1.2, // A ratio affecting number of spaces between words. 
		            }
		        }
		    ]
		}
		*/
		
        // Sample profile that sets advanced conversion options
        // Advanced options are properties of TextExtractor class from ByteScout Text Extractor SDK used in the back-end:
        // https://cdn.bytescout.com/help/BytescoutPDFExtractorSDK/html/8a2bae5a-346f-8338-b5aa-6f3522dca0d4.htm
        static string Profiles = File.ReadAllText("profile.json");


        static void Main(string[] args)
		{
			// Create standard .NET web client instance
			WebClient webClient = new WebClient();

			// Set API Key
			webClient.Headers.Add("x-api-key", API_KEY);

			// URL for `PDF To TXT` API call
			string url = "https://api.pdf.co/v1/pdf/convert/to/text";

			// Prepare requests params as JSON
			Dictionary<string, object> parameters = new Dictionary<string, object>();
			parameters.Add("name", Path.GetFileName(DestinationFile));
			parameters.Add("password", Password);
			parameters.Add("pages", Pages);
			parameters.Add("url", SourceFileUrl);
			parameters.Add("profiles", Profiles);

			// Convert dictionary of params to JSON
			string jsonPayload = JsonConvert.SerializeObject(parameters);

			try
			{
				// Execute POST request with JSON payload
				string response = webClient.UploadString(url, jsonPayload);

				// Parse JSON response
				JObject json = JObject.Parse(response);

				if (json["error"].ToObject<bool>() == false)
				{
					// Get URL of generated TXT file
					string resultFileUrl = json["url"].ToString();

					// Download TXT file
					webClient.DownloadFile(resultFileUrl, DestinationFile);

					Console.WriteLine("Generated TXT file saved as \"{0}\" file.", DestinationFile);
				}
				else
				{
					Console.WriteLine(json["message"].ToString());
				}
			}
			catch (WebException e)
			{
				Console.WriteLine(e.ToString());
			}

			webClient.Dispose();

			Console.WriteLine();
			Console.WriteLine("Press any key...");
			Console.ReadKey();
		}
	}
}
